@@ -183,7 +183,9 @@ output format."
 (defun elfeed-curl-get-capabilities ()
   "Return capabilities plist for the curl at `elfeed-curl-program-name'.
 :version     -- cURL's version string
-:compression -- non-nil if --compressed is supported"
+:compression -- non-nil if --compressed is supported
+:protocols   -- symbol list of supported protocols
+:features    -- string list of supported features"
   (let* ((cache elfeed-curl--capabilities-cache)
          (cache-value (gethash elfeed-curl-program-name cache)))
     (if cache-value
@@ -195,12 +197,21 @@ output format."
                  (setf (point) (point-min))
                  (when (re-search-forward "[.0-9]+" nil t)
                    (match-string 0))))
-              (compression
+              (protocols
                (progn
                  (setf (point) (point-min))
-                 (not (null (re-search-forward "libz\\>" nil t))))))
+                 (when (re-search-forward "^Protocols: \\(.*\\)$" nil t)
+                   (mapcar #'intern (split-string (match-string 1))))))
+              (features
+               (progn
+                 (setf (point) (point-min))
+                 (when (re-search-forward "^Features: \\(.*\\)$")
+                   (split-string (match-string 1))))))
           (setf (gethash elfeed-curl-program-name cache)
-                `(:version ,version :compression ,compression)))))))
+                (list :version version
+                      :compression (not (null (member "libz" features)))
+                      :protocols protocols
+                      :features features)))))))
 
 (defun elfeed-curl-get-version ()
   "Return the version of curl for `elfeed-curl-program-name'."
@@ -252,7 +263,7 @@ abcdefghijklmnopqrstuvwxyz|~"))
         (:header (narrow-to-region h-start h-end))
         (:content (narrow-to-region c-start c-end))))))
 
-(defun elfeed-curl--parse-headers ()
+(defun elfeed-curl--parse-http-headers ()
   "Parse the current HTTP response headers into buffer-locals.
 Sets `elfeed-curl-headers'and `elfeed-curl-status-code'.
 Use `elfeed-curl--narrow' to select a header."
@@ -306,10 +317,11 @@ URL can be a string or a list of URL strings."
         (nconc (nreverse args) url)
       (nreverse (cons url args)))))
 
-(defun elfeed-curl--prepare-response (url n)
+(defun elfeed-curl--prepare-response (url n protocol)
   "Prepare response N for delivery to user."
   (elfeed-curl--narrow :header n)
-  (elfeed-curl--parse-headers)
+  (when (eq protocol 'http)
+    (elfeed-curl--parse-http-headers))
   (setf elfeed-curl-location
         (elfeed-curl--final-location url elfeed-curl-headers))
   (elfeed-curl--narrow :content n)
@@ -328,28 +340,44 @@ DATA is the content to include in the request."
           (coding-system-for-read 'binary))
       (apply #'call-process elfeed-curl-program-name nil t nil args))
     (elfeed-curl--parse-write-out)
-    (elfeed-curl--prepare-response url 0)))
+    (elfeed-curl--prepare-response url 0 (elfeed-curl--protocol-type url))))
+
+(defun elfeed-curl--protocol-type (url)
+  (let ((scheme (intern (or (url-type (url-generic-parse-url url)) "nil"))))
+    (cl-case scheme
+      ((https nil) 'http)
+      (otherwise scheme))))
 
 (defun elfeed-curl--call-callback (buffer n url cb)
   "Prepare the buffer for callback N and call it."
-  (let ((result nil))
+  (let ((result nil)
+        (protocol (elfeed-curl--protocol-type url)))
     (with-current-buffer buffer
       (setf elfeed-curl-error-message "unable to parse curl response")
       (unwind-protect
           (progn
-            (elfeed-curl--prepare-response url n)
-            (if (and (>= elfeed-curl-status-code 400)
-                     (<= elfeed-curl-status-code 599))
-                (setf elfeed-curl-error-message
-                      (format "HTTP %d" elfeed-curl-status-code))
-              (setf result t
-                    elfeed-curl-error-message nil)))
-        ;; Always call callback
-        (unwind-protect
-            (funcall cb result)
-          ;; Always clean up
-          (when (zerop (cl-decf elfeed-curl--refcount))
-            (kill-buffer)))))))
+            (elfeed-curl--prepare-response url n protocol)
+            (cond ((eq protocol 'file)
+                   ;; No status code is returned by curl for file:// urls
+                   (setf result t
+                         elfeed-curl-error-message nil))
+                  ((eq protocol 'gopher)
+                   (setf result t
+                         elfeed-curl-error-message nil
+                         elfeed-curl-status-code nil))
+                  ((and (>= elfeed-curl-status-code 400)
+                        (<= elfeed-curl-status-code 599))
+                   (setf elfeed-curl-error-message
+                         (format "HTTP %d" elfeed-curl-status-code)))
+                  (t
+                   (setf result t
+                         elfeed-curl-error-message nil)))
+            ;; Always call callback
+            (unwind-protect
+                (funcall cb result)
+              ;; Always clean up
+              (when (zerop (cl-decf elfeed-curl--refcount))
+                (kill-buffer))))))))
 
 (defun elfeed-curl--fail-callback (buffer cb)
   "Inform the callback the request failed."
@@ -416,6 +444,7 @@ results will not."
                     elfeed-curl--refcount (length url)))
           (push (cons url cb) elfeed-curl--requests)
           (setf elfeed-curl--refcount 1))
+        (set-process-query-on-exit-flag process nil)
         (setf (process-sentinel process) #'elfeed-curl--sentinel)))))
 
 (defun elfeed-curl--request-key (url headers method data)
