@@ -8,6 +8,8 @@
 (require 'xml-query-tests)
 (require 'elfeed-db-tests)
 (require 'elfeed-lib-tests)
+(require 'elfeed-search-tests)
+(require 'elfeed-curl-tests)
 
 (defvar elfeed-test-rss
   "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
